@@ -29,7 +29,7 @@ from . import lilypond
 
 __title__= 'sphinxnotes-lilypond'
 __license__ = 'BSD'
-__version__ = '1.5'
+__version__ = '1.5.1'
 __author__ = 'Shengyu Zhang'
 __url__ = 'https://sphinx-notes.github.io/lilypond'
 __description__ = 'Sphinx extension for Lilypond'
@@ -307,11 +307,8 @@ def latex_visit_lily_node(self, node:lily_base_node):
         raise nodes.SkipNode
 
     if node.get('audio'):
-        msg = 'audio option is supported for latex builder'
+        msg = 'audio option is not supported for latex builder'
         logger.warning(msg, location=node)
-        sm = nodes.system_message(msg, type='WARNING', level=2, backrefs=[],
-                                  source=node['lilysrc'])
-        sm.walkabout(self)
 
     raise nodes.SkipNode
 
